@@ -1,29 +1,33 @@
 #!/usr/bin/python
 
-import time
-import os
-import logging
-import win32netcon
-import win32net
-import win32ts
-import win32api
-import win32file
-import win32pipe
-import win32security
-import win32process
-import win32con
-import win32com.client
-import pythoncom
-import subprocess
-import socket
-from OVirtAgentLogic import AgentLogicBase, DataRetriverBase
+import _winreg
 import ctypes
 from ctypes import c_ulong, byref, windll, create_unicode_buffer,\
     Structure, sizeof, c_void_p
 from ctypes.util import find_library
 from ctypes.wintypes import DWORD
-import _winreg
 import ctypes.wintypes
+import logging
+import os
+import socket
+import subprocess
+import time
+
+import pythoncom
+import win32api
+import win32com.client
+import win32con
+import win32file
+import win32net
+import win32netcon
+import win32pipe
+import win32process
+import win32security
+import win32ts
+
+from OVirtAgentLogic import AgentLogicBase, DataRetriverBase
+from hooks import Hooks
+
 
 # Constants according to
 # http://msdn.microsoft.com/en-us/library/windows/desktop/ms724878.aspx
@@ -230,6 +234,27 @@ class WinOsTypeHandler:
         return {'name': name, 'version': version}
 
 
+def remove_bcd_useplatformclock():
+    try:
+        subprocess.call(['%SystemRoot%\\sysnative\\bcdedit.exe',
+                         '/deletevalue', '{current}', 'USEPLATFORMCLOCK'],
+                        shell=True)
+    except OSError:
+        logging.info('Failed to set the USEPLATFORMCLOCK flag via '
+                     'bcdedit.exe', exc_info=True)
+
+
+def apply_clock_tuning():
+    osinfo = WinOsTypeHandler().getWinOsType()
+    parts = osinfo.get('version', '6.0').split('.')
+    if parts[0] >= '6':
+        if parts[0] == '6' and parts[1] == '0':
+            # Skip 6.0 and lower
+            pass
+        else:
+            remove_bcd_useplatformclock()
+
+
 class CommandHandlerWin:
 
     def lock_screen(self):
@@ -428,6 +453,9 @@ class WinDataRetriver(DataRetriverBase):
             'type': 'windows',
             'kernel': ''}
 
+    def getContainerList(self):
+        return []
+
     def getAllNetworkInterfaces(self):
         return GetNetworkInterfaces()
 
@@ -508,7 +536,8 @@ class WinDataRetriver(DataRetriverBase):
             elif domain.lower() != self.getMachineName().lower():
                 # Use FQDN as user name if computer is part of a domain.
                 try:
-                    user = u"%s\\%s" % (domain, user)
+                    user_orig = user
+                    user = u"%s\\%s" % (domain, user_orig)
                     user = win32security.TranslateName(
                         user,
                         win32api.NameSamCompatible,
@@ -519,7 +548,9 @@ class WinDataRetriver(DataRetriverBase):
                     if err != 0:
                         raise RuntimeError(err, 'TranslateName')
                 except:
-                    logging.exception("Error on user name translation.")
+                    logging.debug("Error on user name translation. Requested "
+                                  "translation '%s' '%s'", user_orig, domain)
+                    user = u"%s@%s" % (user_orig, domain)
             else:
                 user = u"%s@%s" % (user, domain)
         except:
@@ -656,10 +687,15 @@ class WinDataRetriver(DataRetriverBase):
 
 class WinVdsAgent(AgentLogicBase):
 
-    def __init__(self, config):
+    def __init__(self, config, install_dir):
         AgentLogicBase.__init__(self, config)
         self.dr = WinDataRetriver()
         self.commandHandler = CommandHandlerWin()
+        hooks_dir = os.path.join(install_dir, 'hooks')
+        self.hooks = Hooks(logging.getLogger('Hooks'), hooks_dir)
+
+        if config.getboolean('general', 'apply_timer_configuration'):
+            apply_clock_tuning()
 
     def run(self):
         logging.debug("WinVdsAgent:: run() entered")
